@@ -1,9 +1,29 @@
 #[cfg(not(target_os = "redox"))]
 mod dir;
+#[cfg(not(any(
+    target_os = "ios",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd",
+    target_os = "macos",
+    target_os = "redox",
+    target_os = "wasi"
+)))]
+mod makedev;
 mod types;
 
 #[cfg(not(target_os = "redox"))]
 pub use dir::{Dir, DirEntry};
+#[cfg(not(any(
+    target_os = "ios",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd",
+    target_os = "macos",
+    target_os = "redox",
+    target_os = "wasi"
+)))]
+pub use makedev::{major, makedev, minor};
 #[cfg(not(any(
     target_os = "ios",
     target_os = "macos",
