@@ -9,9 +9,7 @@
 )))]
 use super::conv::ret_u32;
 #[cfg(any(target_os = "android", target_os = "linux"))]
-use super::conv::syscall_ret;
-#[cfg(any(target_os = "android", target_os = "linux"))]
-use super::conv::{syscall_ret_owned_fd, syscall_ret_ssize_t};
+use super::conv::{syscall_ret, syscall_ret_owned_fd, syscall_ret_ssize_t};
 #[cfg(not(any(
     target_os = "ios",
     target_os = "macos",
@@ -990,6 +988,11 @@ pub(crate) fn dup(fd: BorrowedFd<'_>) -> io::Result<OwnedFd> {
     unsafe { ret_owned_fd(libc::dup(borrowed_fd(fd))) }
 }
 
+#[cfg(not(target_os = "wasi"))]
+pub(crate) fn dup2(fd: BorrowedFd<'_>, new: OwnedFd) -> io::Result<OwnedFd> {
+    unsafe { ret_owned_fd(libc::dup2(borrowed_fd(fd), owned_fd(new))) }
+}
+
 #[cfg(not(any(
     target_os = "android",
     target_os = "macos",
@@ -997,7 +1000,7 @@ pub(crate) fn dup(fd: BorrowedFd<'_>) -> io::Result<OwnedFd> {
     target_os = "redox",
     target_os = "wasi"
 )))]
-pub(crate) fn dup2(fd: BorrowedFd<'_>, new: OwnedFd, flags: DupFlags) -> io::Result<OwnedFd> {
+pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: OwnedFd, flags: DupFlags) -> io::Result<OwnedFd> {
     unsafe { ret_owned_fd(libc::dup3(borrowed_fd(fd), owned_fd(new), flags.bits())) }
 }
 
@@ -1007,11 +1010,9 @@ pub(crate) fn dup2(fd: BorrowedFd<'_>, new: OwnedFd, flags: DupFlags) -> io::Res
     target_os = "ios",
     target_os = "redox"
 ))]
-pub(crate) fn dup2(fd: BorrowedFd<'_>, new: OwnedFd, _flags: DupFlags) -> io::Result<OwnedFd> {
-    unsafe {
-        // Android 5.0 has dup3, but libc doesn't have bindings
-        ret_owned_fd(libc::dup2(borrowed_fd(fd), owned_fd(new)))
-    }
+pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: OwnedFd, _flags: DupFlags) -> io::Result<OwnedFd> {
+    // Android 5.0 has dup3, but libc doesn't have bindings
+    dup2(fd, new)
 }
 
 #[cfg(not(any(target_os = "wasi", target_os = "fuchsia")))]
@@ -1135,7 +1136,7 @@ pub(crate) fn pipe() -> io::Result<(OwnedFd, OwnedFd)> {
 }
 
 #[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi")))]
-pub(crate) fn pipe2(flags: PipeFlags) -> io::Result<(OwnedFd, OwnedFd)> {
+pub(crate) fn pipe_with(flags: PipeFlags) -> io::Result<(OwnedFd, OwnedFd)> {
     unsafe {
         let mut result = MaybeUninit::<[OwnedFd; 2]>::uninit();
         ret(libc::pipe2(result.as_mut_ptr().cast::<i32>(), flags.bits()))?;
@@ -1353,13 +1354,21 @@ pub(crate) fn listen(sockfd: BorrowedFd<'_>, backlog: c_int) -> io::Result<()> {
     unsafe { ret(libc::listen(borrowed_fd(sockfd), backlog)) }
 }
 
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
+pub(crate) fn accept(sockfd: BorrowedFd<'_>) -> io::Result<OwnedFd> {
+    unsafe {
+        let owned_fd = ret_owned_fd(libc::accept(borrowed_fd(sockfd), null_mut(), null_mut()))?;
+        Ok(owned_fd)
+    }
+}
+
 #[cfg(not(any(
     target_os = "ios",
     target_os = "macos",
     target_os = "redox",
     target_os = "wasi"
 )))]
-pub(crate) fn accept(sockfd: BorrowedFd<'_>, flags: AcceptFlags) -> io::Result<OwnedFd> {
+pub(crate) fn accept_with(sockfd: BorrowedFd<'_>, flags: AcceptFlags) -> io::Result<OwnedFd> {
     unsafe {
         let owned_fd = ret_owned_fd(libc::accept4(
             borrowed_fd(sockfd),
@@ -1371,13 +1380,27 @@ pub(crate) fn accept(sockfd: BorrowedFd<'_>, flags: AcceptFlags) -> io::Result<O
     }
 }
 
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
+pub(crate) fn acceptfrom(sockfd: BorrowedFd<'_>) -> io::Result<(OwnedFd, SocketAddr)> {
+    unsafe {
+        let mut storage = MaybeUninit::<libc::sockaddr_storage>::uninit();
+        let mut len = size_of::<libc::sockaddr_storage>() as libc::socklen_t;
+        let owned_fd = ret_owned_fd(libc::accept(
+            borrowed_fd(sockfd),
+            storage.as_mut_ptr().cast::<_>(),
+            &mut len,
+        ))?;
+        Ok((owned_fd, decode_sockaddr(storage.as_ptr(), len)))
+    }
+}
+
 #[cfg(not(any(
     target_os = "ios",
     target_os = "macos",
     target_os = "redox",
     target_os = "wasi"
 )))]
-pub(crate) fn acceptfrom(
+pub(crate) fn acceptfrom_with(
     sockfd: BorrowedFd<'_>,
     flags: AcceptFlags,
 ) -> io::Result<(OwnedFd, SocketAddr)> {
@@ -1397,30 +1420,18 @@ pub(crate) fn acceptfrom(
 /// Darwin lacks `accept4`, but does have `accept`. We define
 /// `AcceptFlags` to have no flags, so we can discard it here.
 #[cfg(any(target_os = "ios", target_os = "macos"))]
-pub(crate) fn accept(sockfd: BorrowedFd<'_>, _flags: AcceptFlags) -> io::Result<OwnedFd> {
-    unsafe {
-        let owned_fd = ret_owned_fd(libc::accept(borrowed_fd(sockfd), null_mut(), null_mut()))?;
-        Ok(owned_fd)
-    }
+pub(crate) fn accept_with(sockfd: BorrowedFd<'_>, _flags: AcceptFlags) -> io::Result<OwnedFd> {
+    accept(sockfd)
 }
 
 /// Darwin lacks `accept4`, but does have `accept`. We define
 /// `AcceptFlags` to have no flags, so we can discard it here.
 #[cfg(any(target_os = "ios", target_os = "macos"))]
-pub(crate) fn acceptfrom(
+pub(crate) fn acceptfrom_with(
     sockfd: BorrowedFd<'_>,
     _flags: AcceptFlags,
 ) -> io::Result<(OwnedFd, SocketAddr)> {
-    unsafe {
-        let mut storage = MaybeUninit::<libc::sockaddr_storage>::uninit();
-        let mut len = size_of::<libc::sockaddr_storage>() as libc::socklen_t;
-        let owned_fd = ret_owned_fd(libc::accept(
-            borrowed_fd(sockfd),
-            storage.as_mut_ptr().cast::<_>(),
-            &mut len,
-        ))?;
-        Ok((owned_fd, decode_sockaddr(storage.as_ptr(), len)))
-    }
+    acceptfrom(sockfd)
 }
 
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
@@ -1827,7 +1838,7 @@ pub(crate) fn getppid() -> u32 {
 }
 
 #[inline]
-pub fn sched_yield() {
+pub(crate) fn sched_yield() {
     unsafe {
         let _ = libc::sched_yield();
     }
