@@ -212,6 +212,19 @@ pub(super) fn out<T: Sized>(t: &mut MaybeUninit<T>) -> usize {
 #[inline]
 fn check_error(raw: usize) -> io::Result<()> {
     if (-4095..0).contains(&(raw as isize)) {
+        // Discourage the optimizer from speculating the compuation of the
+        // `Err` above the `if`. The discriminant of the `Result` is often
+        // branched on, so if the optimizer speculates here and replaces the
+        // `if` with a conditional move, it appears to struggle to undo this
+        // once it realizes there's another branch on the same condition.
+        //
+        // It ends up doing a conditional move to produce a Result value
+        // with either the encoded Err or Ok value, and then a branch on the
+        // same condition, where both destinations of the branch have to unpack
+        // the Result. What we want is to do is just branch, and skip encoding
+        // and decoding the Result.
+        let raw = suppress_optimization(raw);
+
         Err(io::Error((raw as u16).wrapping_neg()))
     } else {
         Ok(())
@@ -224,6 +237,9 @@ pub(super) fn ret(raw: usize) -> io::Result<()> {
     // this function is only used for system calls which have no other
     // return value, and this produces smaller code.
     if raw != 0 {
+        // As above, discourage the optimizer from speculating the `Err`.
+        let raw = suppress_optimization(raw);
+
         Err(io::Error((raw as u16).wrapping_neg()))
     } else {
         Ok(())
@@ -263,8 +279,14 @@ pub(super) fn ret_usize(raw: usize) -> io::Result<usize> {
 /// returns an owned file descriptor.
 #[inline]
 pub(super) unsafe fn ret_owned_fd(raw: usize) -> io::Result<OwnedFd> {
-    check_error(raw)?;
-    Ok(OwnedFd::from_raw_fd(raw as RawFd))
+    if (raw as isize) < 0 {
+        // As above, discourage the optimizer from speculating the `Err`.
+        let raw = suppress_optimization(raw);
+
+        Err(io::Error((raw as u16).wrapping_neg()))
+    } else {
+        Ok(OwnedFd::from_raw_fd(raw as RawFd))
+    }
 }
 
 #[inline]
@@ -272,3 +294,20 @@ pub(super) fn ret_void_star(raw: usize) -> io::Result<*mut c_void> {
     check_error(raw)?;
     Ok(raw as *mut c_void)
 }
+
+#[cfg(linux_raw_inline_asm)]
+#[inline(always)]
+fn suppress_optimization(mut t: usize) -> usize {
+    // Safety: This asm block has no semantic effect.
+    unsafe {
+        asm!("/*{0}*/", inlateout(reg) t, options(pure, nomem, preserves_flags));
+    }
+    t
+}
+
+#[cfg(not(linux_raw_inline_asm))]
+#[inline(never)]
+fn suppress_optimization(t: usize) -> usize {
+    // Without inline asm, we can put this in an inline-never function.
+    t
+}
