@@ -248,6 +248,7 @@ pub enum FileType {
 
 impl FileType {
     /// Construct a `FileType` from the `st_mode` field of a `Stat`.
+    #[inline]
     pub const fn from_raw_mode(st_mode: RawMode) -> Self {
         match st_mode & linux_raw_sys::general::S_IFMT {
             linux_raw_sys::general::S_IFREG => Self::RegularFile,
@@ -262,11 +263,13 @@ impl FileType {
     }
 
     /// Construct a `FileType` from the `st_mode` field of a `Stat`.
+    #[inline]
     pub const fn from_mode(st_mode: Mode) -> Self {
         Self::from_raw_mode(st_mode.bits())
     }
 
     /// Construct a `FileType` from the `d_type` field of a `dirent`.
+    #[inline]
     pub(crate) const fn from_dirent_d_type(d_type: u8) -> Self {
         match d_type as u32 {
             linux_raw_sys::general::DT_REG => Self::RegularFile,
@@ -421,7 +424,7 @@ pub type StatFs = linux_raw_sys::general::statfs64;
 /// [`statx`]: crate::fs::statx
 pub type Statx = linux_raw_sys::v5_4::general::statx;
 
-/// `mode_t`.
+/// `mode_t`
 #[cfg(not(any(
     target_arch = "x86",
     target_arch = "sparc",
@@ -430,7 +433,7 @@ pub type Statx = linux_raw_sys::v5_4::general::statx;
 )))]
 pub type RawMode = linux_raw_sys::general::__kernel_mode_t;
 
-/// `mode_t`.
+/// `mode_t
 #[cfg(any(
     target_arch = "x86",
     target_arch = "sparc",
@@ -440,11 +443,11 @@ pub type RawMode = linux_raw_sys::general::__kernel_mode_t;
 // Don't use `__kernel_mode_t` since it's `u16` which differs from `st_size`.
 pub type RawMode = std::os::raw::c_uint;
 
-/// `dev_t`.
+/// `dev_t`
 // Within the kernel the dev_t is 32-bit, but userspace uses a 64-bit field.
 pub type Dev = u64;
 
-/// `__fsword_t`.
+/// `__fsword_t`
 pub type FsWord = linux_raw_sys::general::__fsword_t;
 
 pub use linux_raw_sys::general::{UTIME_NOW, UTIME_OMIT};
