@@ -10,7 +10,10 @@ use io_lifetimes::OwnedFd;
 ))]
 pub use imp::io::PipeFlags;
 
-/// `pipe()`
+/// `pipe()`—Creates a pipe.
+///
+/// This function creates a pipe and returns two file descriptors, for the
+/// reading and writing ends of the pipe, respectively.
 ///
 /// # References
 ///  - [POSIX]
@@ -24,7 +27,10 @@ pub fn pipe() -> io::Result<(OwnedFd, OwnedFd)> {
     imp::syscalls::pipe()
 }
 
-/// `pipe2(flags)`
+/// `pipe2(flags)`—Creates a pipe, with flags.
+///
+/// This function creates a pipe and returns two file descriptors, for the
+/// reading and writing ends of the pipe, respectively.
 ///
 /// # References
 ///  - [Linux]
@@ -32,6 +38,7 @@ pub fn pipe() -> io::Result<(OwnedFd, OwnedFd)> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/pipe2.2.html
 #[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi")))]
 #[inline]
-pub fn pipe2(flags: PipeFlags) -> io::Result<(OwnedFd, OwnedFd)> {
-    imp::syscalls::pipe2(flags)
+#[doc(alias = "pipe2")]
+pub fn pipe_with(flags: PipeFlags) -> io::Result<(OwnedFd, OwnedFd)> {
+    imp::syscalls::pipe_with(flags)
 }
