@@ -11,7 +11,7 @@
 use crate::{imp, io::RawFd};
 use io_lifetimes::BorrowedFd;
 
-/// `STDIN_FILENO`
+/// `STDIN_FILENO`—Standard input.
 ///
 /// # Safety
 ///
@@ -27,11 +27,12 @@ use io_lifetimes::BorrowedFd;
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/stdin.html
 /// [Linux]: https://man7.org/linux/man-pages/man3/stdin.3.html
+#[inline]
 pub unsafe fn stdin() -> BorrowedFd<'static> {
     BorrowedFd::borrow_raw_fd(imp::io::STDIN_FILENO as RawFd)
 }
 
-/// `STDOUT_FILENO`
+/// `STDOUT_FILENO`—Standard output.
 ///
 /// # Safety
 ///
@@ -47,11 +48,12 @@ pub unsafe fn stdin() -> BorrowedFd<'static> {
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/stdout.html
 /// [Linux]: https://man7.org/linux/man-pages/man3/stdout.3.html
+#[inline]
 pub unsafe fn stdout() -> BorrowedFd<'static> {
     BorrowedFd::borrow_raw_fd(imp::io::STDOUT_FILENO as RawFd)
 }
 
-/// `STDERR_FILENO`
+/// `STDERR_FILENO`—Standard error.
 ///
 /// # Safety
 ///
@@ -67,6 +69,7 @@ pub unsafe fn stdout() -> BorrowedFd<'static> {
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/stderr.html
 /// [Linux]: https://man7.org/linux/man-pages/man3/stderr.3.html
+#[inline]
 pub unsafe fn stderr() -> BorrowedFd<'static> {
     BorrowedFd::borrow_raw_fd(imp::io::STDERR_FILENO as RawFd)
 }
